@@ -215,7 +215,7 @@ def parse_to_CGP_object(python_object):
         result += f'#{str(python_object)}'
     
     elif isinstance(python_object, dict):
-        result += '{' + ''.join(f'"{str(x)}" = {parse_to_CGP_object(y)};' for x, y in zip(list(python_object.keys()), list(python_object.values()))) + '}'
+        result += '{' + ''.join(f'"{str(k)}" = {parse_to_CGP_object(v)};' for k, v in python_object.items()) + '}'
             
     elif isinstance(python_object,list):
         result += '(' + ''.join(parse_to_CGP_object(x) + ', ' for x in python_object)[:-2] + ')'
@@ -230,13 +230,13 @@ def parse_to_CGP_object(python_object):
         except AttributeError:
             pass
         
-    elif isinstance(python_object, True):
+    elif python_object is True:
         result += "true"
     
-    elif isinstance(python_object, False):    
+    elif python_object is False:
         result += "false"
         
-    elif isinstance(python_object, None):
+    elif python_object is None:
         result += "null"
         
     return result
\ No newline at end of file
